// mapFunctions.js
// Created by: Jeff Rackauckas & Chris Rackauckas
// The goal of this project is to create a google map to properly display the CSV data onto the specified google map object.
// Dependencies: globalFunctions.js

function createMap(){
    var myOptions = {
	center: new google.maps.LatLng(38.825115,-76.399673),
	zoom: 8,
	mapTypeId: google.maps.MapTypeId.SATELLITE,
	preserveViewport: true,
	minZoom:2
    };
    map = new google.maps.Map(document.getElementById(MAP_CANVAS_DIV),myOptions);
	getData();
}

function createStationDisplays(stations,addRows){
	for(var i=0;i<stations.length;i++){
		for(var t=startTIndex[i];t<stations[i].readings.length;t++){
			 sampleTime = moment(stations[i].readings[t]["SampleDate"]);
			 if(curTime.diff(sampleTime,"days")==0){
				var id = stations[i].StaName + sampleTime.format('L') 
				idfound = false; //check to see if marker was already made
				if(markerArray.length>0){
					for(j=0;j<markerArray.length;j++){
						if(markerArray[j].id==id){
							idfound=true;	
						}
					}
				}
				if(!idfound){
					if((stations[i].readings[t][parameterColor]!=false)&&(stations[i].readings[t][parameterSize]!=false)){
			 			var marker = plotDisplay(stations[i].lat,stations[i].long,stations[i].StaName,stations[i].readings[t][		parameterColor],stations[i].readings[t][parameterSize]);
						markerArray.push(new MarkerStorage(marker,moment(sampleTime.format('L')),id));
						if(addRows){
			 				addReadingsRow(stations[i].StaName,stations[i].readings[t][parameterColor],stations[i].readings[t][parameterSize],sampleTime.format('L'),stations[i].lat,stations[i].long);
						}
					}
				}
				startTIndex[i]=t;
				break;
			}
			if(curTime.diff(sampleTime,"days")<=0){
				startTIndex[i]=t;
				break;
			}
		}
	}
	
}

function chooseDisplayedMarkers(markerArray){
	for(i=0;i<markerArray.length;i++){
		markerArray[i].checkPlot();
	}
}

// Adds a placemark on the map in the given location.
function plotDisplay(lat, lng, name,readingColor,readingSize){
	
	color = chooseColor(readingColor);
	//console.log(parameterThresholds[parameter][0]<parameterThresholds[parameter][1]);
	scaleNum = chooseScale(readingSize);
	// Defines the icon
	// Inside the function to define the color each time.
	var mapIcon = {
		path: google.maps.SymbolPath.CIRCLE,
		fillOpacity: .8,
		fillColor: color,
		strokeOpacity: 1.0,
		strokeColor: "black",
		strokeWeight: 1.0,
		scale: scaleNum
	};
	
	description = name + ", " + parameterColor + "\: " + readingColor + ", " + parameterSize + "\: " + readingSize;
	
	if(showLabels){
		marker = new MarkerWithLabel({
			position: new google.maps.LatLng(lat,lng),
			icon: mapIcon,
			title: description,
			labelContent: description,
			labelAnchor: new google.maps.Point(-10, -5),
			labelClass: "labels", // the CSS class for the label
			labelStyle: {opacity: 0.75},
			map: map,
		});
	}
	else{
		marker = new google.maps.Marker({
			position: new google.maps.LatLng(lat,lng),
			icon: mapIcon,
			title: description,
			map: map,
		});
	}
	return marker;
}

//use to clear markers
//http://stackoverflow.com/questions/1544739/google-maps-api-v3-how-to-remove-all-markers/1544885#1544885
google.maps.Map.prototype.markers = new Array();

google.maps.Map.prototype.getMarkers = function() {
    return this.markers
};

google.maps.Map.prototype.clearMarkers = function() {
    for(var i=0; i<this.markers.length; i++){
        this.markers[i].setMap(null);
    }
    this.markers = new Array();
};

google.maps.Marker.prototype._setMap = google.maps.Marker.prototype.setMap;

google.maps.Marker.prototype.setMap = function(map) {
    if (map) {
        map.markers[map.markers.length] = this;
    }
    this._setMap(map);
}

function MarkerStorage(marker,date,id){
	this.marker=marker;
	this.date=date;
	this.id=id;
	this.on=false;
	this.checkPlot = checkPlot;
	this.moused = false; //By default, all are not moused. When you scoll over one, it is set to true.
	this.setMoused = setMoused;
	this.resetMoused = resetMoused;
	
	function checkPlot(){
		if(MOUSEOVER_STATE){
			if(this.moused){
				this.on=true;
			}
			else{
				this.on=false;
			}
		}
		else{
			if(curTime.diff(this.date,"days")>=0 && curTime.diff(this.date,"days")<=stayTime-1){	
				this.on=true;
			}
			else{
				this.on=false;
			}
		}
		if(this.on && this.marker.map!=map){
			this.marker.setMap(map);
		}
		if(!this.on){
			this.marker.setMap(null);
		}
	}
	
	function setMoused(id){
		if(this.id==id){
			this.moused=true;
		}
	}
	function resetMoused(){
		this.moused=false;	
	}
}